@@ -24,13 +24,14 @@
 #include <QDBusConnection>
 #include <QCoreApplication>
 #include <QTextStream>
+#include <QFile>
 
 #include <KAboutData>
-#include <KLocalizedString>
 
 #include "interfaces/devicesmodel.h"
 #include "interfaces/notificationsmodel.h"
 #include "interfaces/dbusinterfaces.h"
+#include "interfaces/dbushelpers.h"
 #include "kdeconnect-version.h"
 
 int main(int argc, char** argv)
@@ -66,6 +67,8 @@ int main(int argc, char** argv)
     parser.addOption(QCommandLineOption(QStringLiteral("encryption-info"), i18n("Get encryption info about said device")));
     parser.addOption(QCommandLineOption(QStringLiteral("list-commands"), i18n("Lists remote commands and their ids")));
     parser.addOption(QCommandLineOption(QStringLiteral("execute-command"), i18n("Executes a remote command by id"), QStringLiteral("id")));
+    parser.addOption(QCommandLineOption(QStringList{QStringLiteral("k"), QStringLiteral("send-keys")}, i18n("Sends keys to a said device")));
+    parser.addOption(QCommandLineOption(QStringLiteral("my-id"), i18n("Display this device's id and exit")));
     about.setupCommandLine(&parser);
 
     parser.addHelpOption();
@@ -75,19 +78,19 @@ int main(int argc, char** argv)
     const QString id = "kdeconnect-cli-"+QString::number(QCoreApplication::applicationPid());
     DaemonDbusInterface iface;
 
-    if(parser.isSet(QStringLiteral("l")) || parser.isSet(QStringLiteral("a"))) {
+    if (parser.isSet(QStringLiteral("my-id"))) {
+        QTextStream(stdout) << iface.selfId() << endl;
+    } else if (parser.isSet(QStringLiteral("l")) || parser.isSet(QStringLiteral("a"))) {
         bool paired = true, reachable = false;
         if (parser.isSet(QStringLiteral("a"))) {
             reachable = true;
         } else {
-            iface.acquireDiscoveryMode(id);
+            blockOnReply(iface.acquireDiscoveryMode(id));
             QThread::sleep(2);
         }
-        QDBusPendingReply<QStringList> reply = iface.devices(paired, reachable);
-        reply.waitForFinished();
+        const QStringList devices = blockOnReply<QStringList>(iface.devices(paired, reachable));
 
-        const QStringList devices = reply.value();
-        Q_FOREACH (const QString& id, devices) {
+        for (const QString& id : devices) {
             if (parser.isSet(QStringLiteral("id-only"))) {
                 QTextStream(stdout) << id << endl;
             } else {
@@ -112,15 +115,15 @@ int main(int argc, char** argv)
             QTextStream(stderr) << i18n("No devices found") << endl;
         }
 
-        iface.releaseDiscoveryMode(id);
+        blockOnReply(iface.releaseDiscoveryMode(id));
     } else if(parser.isSet(QStringLiteral("refresh"))) {
         QDBusMessage msg = QDBusMessage::createMethodCall(QStringLiteral("org.kde.kdeconnect"), QStringLiteral("/modules/kdeconnect"), QStringLiteral("org.kde.kdeconnect.daemon"), QStringLiteral("forceOnNetworkChange"));
-        QDBusConnection::sessionBus().call(msg);
+        blockOnReply(QDBusConnection::sessionBus().asyncCall(msg));
     } else {
 
         QString device = parser.value(QStringLiteral("device"));
         if (device.isEmpty() && parser.isSet(QStringLiteral("name"))) {
-            device = iface.deviceIdByName(parser.value(QStringLiteral("name")));
+            device = blockOnReply(iface.deviceIdByName(parser.value(QStringLiteral("name"))));
             if (device.isEmpty()) {
                 QTextStream(stderr) << "Couldn't find device: " << parser.value(QStringLiteral("name")) << endl;
                 return 1;
@@ -128,7 +131,7 @@ int main(int argc, char** argv)
         }
         if(device.isEmpty()) {
             QTextStream(stderr) << i18n("No device specified") << endl;
-            return 1;
+            parser.showHelp(1);
         }
 
         if(parser.isSet(QStringLiteral("share"))) {
@@ -137,7 +140,7 @@ int main(int argc, char** argv)
             if(!url.isEmpty() && !device.isEmpty()) {
                 QDBusMessage msg = QDBusMessage::createMethodCall(QStringLiteral("org.kde.kdeconnect"), "/modules/kdeconnect/devices/"+device+"/share", QStringLiteral("org.kde.kdeconnect.device.share"), QStringLiteral("shareUrl"));
                 msg.setArguments(QVariantList() << url.toString());
-                QDBusConnection::sessionBus().call(msg);
+                blockOnReply(QDBusConnection::sessionBus().asyncCall(msg));
             } else {
                 QTextStream(stderr) << (i18n("Couldn't share %1", url.toString())) << endl;
             }
@@ -147,9 +150,9 @@ int main(int argc, char** argv)
                 //Device doesn't exist, go into discovery mode and wait up to 30 seconds for the device to appear
                 QEventLoop wait;
                 QTextStream(stderr) << i18n("waiting for device...") << endl;
-                iface.acquireDiscoveryMode(id);
+                blockOnReply(iface.acquireDiscoveryMode(id));
 
-                QObject::connect(&iface, &DaemonDbusInterface::deviceAdded, [&](const QString &deviceAddedId) {
+                QObject::connect(&iface, &DaemonDbusInterface::deviceAdded, [&](const QString& deviceAddedId) {
                     if (device == deviceAddedId) {
                         wait.quit();
                     }
@@ -161,24 +164,22 @@ int main(int argc, char** argv)
 
             if (!dev.isReachable()) {
                 QTextStream(stderr) << i18n("Device not found") << endl;
-            } else if(dev.property("isPaired").toBool()) {
+            } else if(blockOnReply<bool>(dev.isTrusted())) {
                 QTextStream(stderr) << i18n("Already paired") << endl;
             } else {
                 QTextStream(stderr) << i18n("Pair requested") << endl;
-                QDBusPendingReply<void> req = dev.requestPair();
-                req.waitForFinished();
+                blockOnReply(dev.requestPair());
             }
-            iface.releaseDiscoveryMode(id);
+            blockOnReply(iface.releaseDiscoveryMode(id));
         } else if(parser.isSet(QStringLiteral("unpair"))) {
             DeviceDbusInterface dev(device);
             if (!dev.isReachable()) {
                 QTextStream(stderr) << i18n("Device does not exist") << endl;
-            } else if(!dev.property("isPaired").toBool()) {
+            } else if(!dev.isTrusted()) {
                 QTextStream(stderr) << i18n("Already not paired") << endl;
             } else {
                 QTextStream(stderr) << i18n("Unpaired") << endl;
-                QDBusPendingReply<void> req = dev.unpair();
-                req.waitForFinished();
+                blockOnReply(dev.unpair());
             }
         } else if(parser.isSet(QStringLiteral("ping")) || parser.isSet(QStringLiteral("ping-msg"))) {
             QDBusMessage msg = QDBusMessage::createMethodCall(QStringLiteral("org.kde.kdeconnect"), "/modules/kdeconnect/devices/"+device+"/ping", QStringLiteral("org.kde.kdeconnect.device.ping"), QStringLiteral("sendPing"));
@@ -186,19 +187,37 @@ int main(int argc, char** argv)
                 QString message = parser.value(QStringLiteral("ping-msg"));
                 msg.setArguments(QVariantList() << message);
             }
-            QDBusConnection::sessionBus().call(msg);
+            blockOnReply(QDBusConnection::sessionBus().asyncCall(msg));
         } else if(parser.isSet(QStringLiteral("send-sms"))) {
             if (parser.isSet(QStringLiteral("destination"))) {
                 QDBusMessage msg = QDBusMessage::createMethodCall(QStringLiteral("org.kde.kdeconnect"), "/modules/kdeconnect/devices/"+device+"/telephony", QStringLiteral("org.kde.kdeconnect.device.telephony"), QStringLiteral("sendSms"));
                 msg.setArguments({ parser.value("destination"), parser.value("send-sms") });
-                QDBusConnection::sessionBus().call(msg);
+                blockOnReply(QDBusConnection::sessionBus().asyncCall(msg));
             } else {
                 QTextStream(stderr) << i18n("error: should specify the SMS's recipient by passing --destination <phone number>");
                 return 1;
             }
         } else if(parser.isSet(QStringLiteral("ring"))) {
             QDBusMessage msg = QDBusMessage::createMethodCall(QStringLiteral("org.kde.kdeconnect"), "/modules/kdeconnect/devices/"+device+"/findmyphone", QStringLiteral("org.kde.kdeconnect.device.findmyphone"), QStringLiteral("ring"));
-            QDBusConnection::sessionBus().call(msg);
+            blockOnReply(QDBusConnection::sessionBus().asyncCall(msg));
+        } else if(parser.isSet("send-keys")) {
+            QString seq = parser.value("send-keys");
+            QDBusMessage msg = QDBusMessage::createMethodCall("org.kde.kdeconnect", "/modules/kdeconnect/devices/"+device+"/remotekeyboard", "org.kde.kdeconnect.device.remotekeyboard", "sendKeyPress");
+            if (seq.trimmed() == QLatin1String("-")) {
+                // from file
+                QFile in;
+                if(in.open(stdin,QIODevice::ReadOnly | QIODevice::Unbuffered)) {
+                    while (!in.atEnd()) {
+                        QByteArray line = in.readLine();  // sanitize to ASCII-codes > 31?
+                        msg.setArguments({QString(line), -1, false, false, false});
+                        blockOnReply(QDBusConnection::sessionBus().asyncCall(msg));
+                    }
+                    in.close();
+                }
+            } else {
+                msg.setArguments({seq, -1, false, false, false});
+                blockOnReply(QDBusConnection::sessionBus().asyncCall(msg));
+            }
         } else if(parser.isSet(QStringLiteral("list-notifications"))) {
             NotificationsModel notifications;
             notifications.setDeviceId(device);
@@ -214,18 +233,13 @@ int main(int argc, char** argv)
                 const QJsonObject cont = it->toObject();
                 QTextStream(stdout) << it.key() << ": " << cont.value(QStringLiteral("name")).toString() << ": " << cont.value(QStringLiteral("command")).toString() << endl;
             }
-            const auto err = iface.lastError();
-            if (err.isValid()) {
-                QTextStream(stderr) << err.message() << endl;
-            }
         } else if(parser.isSet(QStringLiteral("execute-command"))) {
             RemoteCommandsDbusInterface iface(device);
-            iface.triggerCommand(parser.value(QStringLiteral("execute-command")));
+            blockOnReply(iface.triggerCommand(parser.value(QStringLiteral("execute-command"))));
         } else if(parser.isSet(QStringLiteral("encryption-info"))) {
             DeviceDbusInterface dev(device);
-            QDBusPendingReply<QString> devReply = dev.encryptionInfo(); // QSsl::Der = 1
-            devReply.waitForFinished();
-            QTextStream(stderr) << devReply.value() << endl;
+            QString info = blockOnReply<QString>(dev.encryptionInfo()); // QSsl::Der = 1
+            QTextStream(stdout) << info << endl;
         } else {
             QTextStream(stderr) << i18n("Nothing to be done") << endl;
         }
