@@ -35,14 +35,13 @@
 #include "kdeconnectplugin.h"
 #include "pluginloader.h"
 #include "backends/devicelink.h"
+#include "backends/lan/landevicelink.h"
 #include "backends/linkprovider.h"
 #include "networkpackage.h"
 #include "kdeconnectconfig.h"
 #include "daemon.h"
 
-Q_LOGGING_CATEGORY(KDECONNECT_CORE, "kdeconnect.core")
-
-static void warn(const QString &info)
+static void warn(const QString& info)
 {
     qWarning() << "Device pairing error" << info;
 }
@@ -50,7 +49,7 @@ static void warn(const QString &info)
 Device::Device(QObject* parent, const QString& id)
     : QObject(parent)
     , m_deviceId(id)
-    , m_protocolVersion(NetworkPackage::ProtocolVersion) //We don't know it yet
+    , m_protocolVersion(NetworkPackage::s_protocolVersion) //We don't know it yet
 {
     KdeConnectConfig::DeviceInfo info = KdeConnectConfig::instance()->getTrustedDevice(id);
 
@@ -104,7 +103,7 @@ void Device::reloadPlugins()
 
         PluginLoader* loader = PluginLoader::instance();
 
-        Q_FOREACH (const QString& pluginName, m_supportedPlugins) {
+        for (const QString& pluginName : qAsConst(m_supportedPlugins)) {
             const KPluginMetaData service = loader->getPluginInfo(pluginName);
 
             const bool pluginEnabled = isPluginEnabled(pluginName);
@@ -118,7 +117,7 @@ void Device::reloadPlugins()
                 }
                 Q_ASSERT(plugin);
 
-                Q_FOREACH (const QString& interface, incomingCapabilities) {
+                for (const QString& interface : incomingCapabilities) {
                     newPluginsByIncomingCapability.insert(interface, plugin);
                 }
 
@@ -135,9 +134,15 @@ void Device::reloadPlugins()
     m_plugins = newPluginMap;
     m_pluginsByIncomingCapability = newPluginsByIncomingCapability;
 
-    //TODO: see how it works in Android (only done once, when created)
-    Q_FOREACH(KdeConnectPlugin* plugin, m_plugins) {
+    QDBusConnection bus = QDBusConnection::sessionBus();
+    for (KdeConnectPlugin* plugin : qAsConst(m_plugins)) {
+        //TODO: see how it works in Android (only done once, when created)
         plugin->connected();
+
+        const QString dbusPath = plugin->dbusPath();
+        if (!dbusPath.isEmpty()) {
+            bus.registerObject(dbusPath, plugin, QDBusConnection::ExportAllProperties | QDBusConnection::ExportScriptableInvokables | QDBusConnection::ExportScriptableSignals | QDBusConnection::ExportScriptableSlots);
+        }
     }
     if (differentPlugins) {
         Q_EMIT pluginsChanged();
@@ -161,17 +166,18 @@ void Device::requestPair()
         return;
     }
 
-    Q_FOREACH(DeviceLink* dl, m_deviceLinks) {
+    for (DeviceLink* dl : qAsConst(m_deviceLinks)) {
         dl->userRequestsPair();
     }
 }
 
 void Device::unpair()
 {
-    Q_FOREACH(DeviceLink* dl, m_deviceLinks) {
+    for (DeviceLink* dl : qAsConst(m_deviceLinks)) {
         dl->userRequestsUnpair();
     }
     KdeConnectConfig::instance()->removeTrustedDevice(id());
+    Q_EMIT trustedChanged(false);
 }
 
 void Device::pairStatusChanged(DeviceLink::PairStatus status)
@@ -179,7 +185,7 @@ void Device::pairStatusChanged(DeviceLink::PairStatus status)
     if (status == DeviceLink::NotPaired) {
         KdeConnectConfig::instance()->removeTrustedDevice(id());
 
-        Q_FOREACH(DeviceLink* dl, m_deviceLinks) {
+        for (DeviceLink* dl : qAsConst(m_deviceLinks)) {
             if (dl != sender()) {
                 dl->setPairStatus(DeviceLink::NotPaired);
             }
@@ -191,7 +197,7 @@ void Device::pairStatusChanged(DeviceLink::PairStatus status)
     reloadPlugins(); //Will load/unload plugins
 
     bool isTrusted = (status == DeviceLink::Paired);
-    Q_EMIT trustedChanged(isTrusted? Trusted : NotTrusted);
+    Q_EMIT trustedChanged(isTrusted);
     Q_ASSERT(isTrusted == this->isTrusted());
 }
 
@@ -204,11 +210,15 @@ void Device::addLink(const NetworkPackage& identityPackage, DeviceLink* link)
 {
     //qCDebug(KDECONNECT_CORE) << "Adding link to" << id() << "via" << link->provider();
 
-    Q_ASSERT(!m_deviceLinks.contains(link));
+    setName(identityPackage.get<QString>(QStringLiteral("deviceName")));
+    m_deviceType = str2type(identityPackage.get<QString>(QStringLiteral("deviceType")));
+
+    if (m_deviceLinks.contains(link))
+        return;
 
     m_protocolVersion = identityPackage.get<int>(QStringLiteral("protocolVersion"), -1);
-    if (m_protocolVersion != NetworkPackage::ProtocolVersion) {
-        qCWarning(KDECONNECT_CORE) << m_deviceName << "- warning, device uses a different protocol version" << m_protocolVersion << "expected" << NetworkPackage::ProtocolVersion;
+    if (m_protocolVersion != NetworkPackage::s_protocolVersion) {
+        qCWarning(KDECONNECT_CORE) << m_deviceName << "- warning, device uses a different protocol version" << m_protocolVersion << "expected" << NetworkPackage::s_protocolVersion;
     }
 
     connect(link, &QObject::destroyed,
@@ -216,10 +226,6 @@ void Device::addLink(const NetworkPackage& identityPackage, DeviceLink* link)
 
     m_deviceLinks.append(link);
 
-    //re-read the device name from the identityPackage because it could have changed
-    setName(identityPackage.get<QString>(QStringLiteral("deviceName")));
-    m_deviceType = str2type(identityPackage.get<QString>(QStringLiteral("deviceType")));
-
     //Theoretically we will never add two links from the same provider (the provider should destroy
     //the old one before this is called), so we do not have to worry about destroying old links.
     //-- Actually, we should not destroy them or the provider will store an invalid ref!
@@ -243,13 +249,60 @@ void Device::addLink(const NetworkPackage& identityPackage, DeviceLink* link)
     reloadPlugins();
 
     if (m_deviceLinks.size() == 1) {
-        Q_EMIT reachableStatusChanged();
+        Q_EMIT reachableChanged(true);
     }
 
     connect(link, &DeviceLink::pairStatusChanged, this, &Device::pairStatusChanged);
+    connect(link, &DeviceLink::pairingRequest, this, &Device::addPairingRequest);
+    connect(link, &DeviceLink::pairingRequestExpired, this, &Device::removePairingRequest);
     connect(link, &DeviceLink::pairingError, this, &Device::pairingError);
 }
 
+void Device::addPairingRequest(PairingHandler* handler)
+{
+    const bool wasEmpty = m_pairRequests.isEmpty();
+    m_pairRequests.insert(handler);
+
+    if (wasEmpty != m_pairRequests.isEmpty())
+        Q_EMIT hasPairingRequestsChanged(!m_pairRequests.isEmpty());
+}
+
+void Device::removePairingRequest(PairingHandler* handler)
+{
+    const bool wasEmpty = m_pairRequests.isEmpty();
+    m_pairRequests.remove(handler);
+
+    if (wasEmpty != m_pairRequests.isEmpty())
+        Q_EMIT hasPairingRequestsChanged(!m_pairRequests.isEmpty());
+}
+
+bool Device::hasPairingRequests() const
+{
+    return !m_pairRequests.isEmpty();
+}
+
+void Device::acceptPairing()
+{
+    if (m_pairRequests.isEmpty())
+        qWarning() << "no pair requests to accept!";
+
+    //copying because the pairing handler will be removed upon accept
+    const auto prCopy = m_pairRequests;
+    for (auto ph: prCopy)
+        ph->acceptPairing();
+}
+
+void Device::rejectPairing()
+{
+    if (m_pairRequests.isEmpty())
+        qWarning() << "no pair requests to reject!";
+
+    //copying because the pairing handler will be removed upon reject
+    const auto prCopy = m_pairRequests;
+    for (auto ph: prCopy)
+        ph->rejectPairing();
+}
+
 void Device::linkDestroyed(QObject* o)
 {
     removeLink(static_cast<DeviceLink*>(o));
@@ -263,7 +316,7 @@ void Device::removeLink(DeviceLink* link)
 
     if (m_deviceLinks.isEmpty()) {
         reloadPlugins();
-        Q_EMIT reachableStatusChanged();
+        Q_EMIT reachableChanged(false);
     }
 }
 
@@ -273,7 +326,7 @@ bool Device::sendPackage(NetworkPackage& np)
     Q_ASSERT(isTrusted());
 
     //Maybe we could block here any package that is not an identity or a pairing package to prevent sending non encrypted data
-    Q_FOREACH(DeviceLink* dl, m_deviceLinks) {
+    for (DeviceLink* dl : qAsConst(m_deviceLinks)) {
         if (dl->sendPackage(np)) return true;
     }
 
@@ -288,7 +341,7 @@ void Device::privateReceivedPackage(const NetworkPackage& np)
         if (plugins.isEmpty()) {
             qWarning() << "discarding unsupported package" << np.type() << "for" << name();
         }
-        Q_FOREACH (KdeConnectPlugin* plugin, plugins) {
+        for (KdeConnectPlugin* plugin : plugins) {
             plugin->receivePackage(np);
         }
     } else {
@@ -307,7 +360,7 @@ QStringList Device::availableLinks() const
 {
     QStringList sl;
     sl.reserve(m_deviceLinks.size());
-    Q_FOREACH(DeviceLink* dl, m_deviceLinks) {
+    for (DeviceLink* dl : qAsConst(m_deviceLinks)) {
         sl.append(dl->provider()->name());
     }
     return sl;
@@ -328,7 +381,18 @@ void Device::cleanUnneededLinks() {
     }
 }
 
-Device::DeviceType Device::str2type(const QString &deviceType) {
+QHostAddress Device::getLocalIpAddress() const
+{
+    for (DeviceLink* dl : m_deviceLinks) {
+        LanDeviceLink* ldl = dynamic_cast<LanDeviceLink*>(dl);
+        if (ldl) {
+            return ldl->hostAddress();
+        }
+    }
+    return QHostAddress::Null;
+}
+
+Device::DeviceType Device::str2type(const QString& deviceType) {
     if (deviceType == QLatin1String("desktop")) return Desktop;
     if (deviceType == QLatin1String("laptop")) return Laptop;
     if (deviceType == QLatin1String("smartphone") || deviceType == QLatin1String("phone")) return Phone;
@@ -367,10 +431,10 @@ QString Device::iconForStatus(bool reachable, bool trusted) const
     QString status = (reachable? (trusted? QStringLiteral("connected") : QStringLiteral("disconnected")) : QStringLiteral("trusted"));
     QString type = type2str(deviceType);
 
-    return type+'-'+status;
+    return type+status;
 }
 
-void Device::setName(const QString &name)
+void Device::setName(const QString& name)
 {
     if (m_deviceName != name) {
         m_deviceName = name;
