@@ -43,13 +43,13 @@ struct KdeConnectConfigPrivate {
 
     // The Initializer object sets things up, and also does cleanup when it goes out of scope
     // Note it's not being used anywhere. That's intended
-    QCA::Initializer mQcaInitializer;
+    QCA::Initializer m_qcaInitializer;
 
-    QCA::PrivateKey privateKey;
-    QSslCertificate certificate; // Use QSslCertificate instead of QCA::Certificate due to compatibility with QSslSocket
+    QCA::PrivateKey m_privateKey;
+    QSslCertificate m_certificate; // Use QSslCertificate instead of QCA::Certificate due to compatibility with QSslSocket
 
-    QSettings* config;
-    QSettings* trusted_devices;
+    QSettings* m_config;
+    QSettings* m_trustedDevices;
 
 };
 
@@ -64,6 +64,7 @@ KdeConnectConfig::KdeConnectConfig()
 {
     //qCDebug(KDECONNECT_CORE) << "QCA supported capabilities:" << QCA::supportedFeatures().join(",");
     if(!QCA::isSupported("rsa")) {
+        qCritical() << "Could not find support for RSA in your QCA installation";
         Daemon::instance()->reportError(
                              i18n("KDE Connect failed to start"),
                              i18n("Could not find support for RSA in your QCA installation. If your "
@@ -76,17 +77,8 @@ KdeConnectConfig::KdeConnectConfig()
     QDir().mkpath(baseConfigDir().path());
 
     //.config/kdeconnect/config
-    d->config = new QSettings(baseConfigDir().absoluteFilePath("config"), QSettings::IniFormat);
-    d->trusted_devices = new QSettings(baseConfigDir().absoluteFilePath("trusted_devices"), QSettings::IniFormat);
-
-    //Register my own id if not there yet
-    if (!d->config->contains("id")) {
-        QString uuid = QUuid::createUuid().toString();
-        DbusHelper::filterNonExportableCharacters(uuid);
-        d->config->setValue("id", uuid);
-        d->config->sync();
-        qCDebug(KDECONNECT_CORE) << "My id:" << uuid;
-    }
+    d->m_config = new QSettings(baseConfigDir().absoluteFilePath(QStringLiteral("config")), QSettings::IniFormat);
+    d->m_trustedDevices = new QSettings(baseConfigDir().absoluteFilePath(QStringLiteral("trusted_devices")), QSettings::IniFormat);
 
     const QFile::Permissions strict = QFile::ReadOwner | QFile::WriteOwner | QFile::ReadUser | QFile::WriteUser;
 
@@ -94,17 +86,17 @@ KdeConnectConfig::KdeConnectConfig()
     QFile privKey(keyPath);
     if (privKey.exists() && privKey.open(QIODevice::ReadOnly)) {
 
-        d->privateKey = QCA::PrivateKey::fromPEM(privKey.readAll());
+        d->m_privateKey = QCA::PrivateKey::fromPEM(privKey.readAll());
 
     } else {
 
-        d->privateKey = QCA::KeyGenerator().createRSA(2048);
+        d->m_privateKey = QCA::KeyGenerator().createRSA(2048);
 
         if (!privKey.open(QIODevice::ReadWrite | QIODevice::Truncate))  {
-            Daemon::instance()->reportError(QLatin1String("KDE Connect"), i18n("Could not store private key file: %1", keyPath));
+            Daemon::instance()->reportError(QStringLiteral("KDE Connect"), i18n("Could not store private key file: %1", keyPath));
         } else {
             privKey.setPermissions(strict);
-            privKey.write(d->privateKey.toPEM().toLatin1());
+            privKey.write(d->m_privateKey.toPEM().toLatin1());
         }
     }
 
@@ -112,10 +104,16 @@ KdeConnectConfig::KdeConnectConfig()
     QFile cert(certPath);
     if (cert.exists() && cert.open(QIODevice::ReadOnly)) {
 
-        d->certificate = QSslCertificate::fromPath(certPath).at(0);
+        d->m_certificate = QSslCertificate::fromPath(certPath).at(0);
 
     } else {
 
+        // No certificate yet. Probably first run. Let's generate one!
+
+        QString uuid = QUuid::createUuid().toString();
+        DbusHelper::filterNonExportableCharacters(uuid);
+        qCDebug(KDECONNECT_CORE) << "My id:" << uuid;
+
         // FIXME: We only use QCA here to generate the cert and key, would be nice to get rid of it completely.
         // The same thing we are doing with QCA could be done invoking openssl (altought it's potentially less portable):
         // openssl req -new -x509 -sha256 -newkey rsa:2048 -nodes -keyout privateKey.pem -days 3650 -out certificate.pem -subj "/O=KDE/OU=KDE Connect/CN=_e6e29ad4_2b31_4b6d_8f7a_9872dbaa9095_"
@@ -124,21 +122,21 @@ KdeConnectConfig::KdeConnectConfig()
         QDateTime startTime = QDateTime::currentDateTime().addYears(-1);
         QDateTime endTime = startTime.addYears(10);
         QCA::CertificateInfo certificateInfo;
-        certificateInfo.insert(QCA::CommonName,deviceId());
-        certificateInfo.insert(QCA::Organization,"KDE");
-        certificateInfo.insert(QCA::OrganizationalUnit,"Kde connect");
+        certificateInfo.insert(QCA::CommonName, uuid);
+        certificateInfo.insert(QCA::Organization,QStringLiteral("KDE"));
+        certificateInfo.insert(QCA::OrganizationalUnit,QStringLiteral("Kde connect"));
         certificateOptions.setInfo(certificateInfo);
         certificateOptions.setFormat(QCA::PKCS10);
         certificateOptions.setSerialNumber(QCA::BigInteger(10));
         certificateOptions.setValidityPeriod(startTime, endTime);
 
-        d->certificate = QSslCertificate(QCA::Certificate(certificateOptions, d->privateKey).toPEM().toLatin1());
+        d->m_certificate = QSslCertificate(QCA::Certificate(certificateOptions, d->m_privateKey).toPEM().toLatin1());
 
         if (!cert.open(QIODevice::ReadWrite | QIODevice::Truncate))  {
-            Daemon::instance()->reportError(QLatin1String("KDE Connect"), i18n("Could not store certificate file: %1", certPath));
+            Daemon::instance()->reportError(QStringLiteral("KDE Connect"), i18n("Could not store certificate file: %1", certPath));
         } else {
             cert.setPermissions(strict);
-            cert.write(d->certificate.toPem());
+            cert.write(d->m_certificate.toPem());
         }
     }
 
@@ -151,122 +149,121 @@ KdeConnectConfig::KdeConnectConfig()
 QString KdeConnectConfig::name()
 {
     QString defaultName = qgetenv("USER") + '@' + QHostInfo::localHostName();
-    QString name = d->config->value("name", defaultName).toString();
+    QString name = d->m_config->value(QStringLiteral("name"), defaultName).toString();
     return name;
 }
 
-void KdeConnectConfig::setName(QString name)
+void KdeConnectConfig::setName(const QString& name)
 {
-    d->config->setValue("name", name);
-    d->config->sync();
+    d->m_config->setValue(QStringLiteral("name"), name);
+    d->m_config->sync();
 }
 
 QString KdeConnectConfig::deviceType()
 {
-    return "desktop"; // TODO
+    return QStringLiteral("desktop"); // TODO
 }
 
 QString KdeConnectConfig::deviceId()
 {
-    QString id = d->config->value("id", "").toString();
-    return id;
+    return d->m_certificate.subjectInfo( QSslCertificate::CommonName ).constFirst();
 }
 
 QString KdeConnectConfig::privateKeyPath()
 {
-    return baseConfigDir().absoluteFilePath("privateKey.pem");
+    return baseConfigDir().absoluteFilePath(QStringLiteral("privateKey.pem"));
 }
 
 QCA::PrivateKey KdeConnectConfig::privateKey()
 {
-    return d->privateKey;
+    return d->m_privateKey;
 }
 
 QCA::PublicKey KdeConnectConfig::publicKey()
 {
-    return d->privateKey.toPublicKey();
+    return d->m_privateKey.toPublicKey();
 }
 
 QString KdeConnectConfig::certificatePath()
 {
-    return baseConfigDir().absoluteFilePath("certificate.pem");
+    return baseConfigDir().absoluteFilePath(QStringLiteral("certificate.pem"));
 }
 
 QSslCertificate KdeConnectConfig::certificate()
 {
-    return d->certificate;
+    return d->m_certificate;
 }
 
 QDir KdeConnectConfig::baseConfigDir()
 {
     QString configPath = QStandardPaths::writableLocation(QStandardPaths::ConfigLocation);
-    QString kdeconnectConfigPath = QDir(configPath).absoluteFilePath("kdeconnect");
+    QString kdeconnectConfigPath = QDir(configPath).absoluteFilePath(QStringLiteral("kdeconnect"));
     return QDir(kdeconnectConfigPath);
 }
 
 QStringList KdeConnectConfig::trustedDevices()
 {
-    const QStringList& list = d->trusted_devices->childGroups();
+    const QStringList& list = d->m_trustedDevices->childGroups();
     return list;
 }
 
 
-void KdeConnectConfig::addTrustedDevice(const QString &id, const QString &name, const QString &type)
+void KdeConnectConfig::addTrustedDevice(const QString& id, const QString& name, const QString& type)
 {
-    d->trusted_devices->beginGroup(id);
-    d->trusted_devices->setValue("name", name);
-    d->trusted_devices->setValue("type", type);
-    d->trusted_devices->endGroup();
-    d->trusted_devices->sync();
+    d->m_trustedDevices->beginGroup(id);
+    d->m_trustedDevices->setValue(QStringLiteral("name"), name);
+    d->m_trustedDevices->setValue(QStringLiteral("type"), type);
+    d->m_trustedDevices->endGroup();
+    d->m_trustedDevices->sync();
 
     QDir().mkpath(deviceConfigDir(id).path());
 }
 
-KdeConnectConfig::DeviceInfo KdeConnectConfig::getTrustedDevice(const QString &id)
+KdeConnectConfig::DeviceInfo KdeConnectConfig::getTrustedDevice(const QString& id)
 {
-    d->trusted_devices->beginGroup(id);
+    d->m_trustedDevices->beginGroup(id);
 
     KdeConnectConfig::DeviceInfo info;
-    info.deviceName = d->trusted_devices->value("name", QLatin1String("unnamed")).toString();
-    info.deviceType = d->trusted_devices->value("type", QLatin1String("unknown")).toString();
+    info.deviceName = d->m_trustedDevices->value(QStringLiteral("name"), QLatin1String("unnamed")).toString();
+    info.deviceType = d->m_trustedDevices->value(QStringLiteral("type"), QLatin1String("unknown")).toString();
 
-    d->trusted_devices->endGroup();
+    d->m_trustedDevices->endGroup();
     return info;
 }
 
-void KdeConnectConfig::removeTrustedDevice(const QString &deviceId)
+void KdeConnectConfig::removeTrustedDevice(const QString& deviceId)
 {
-    d->trusted_devices->remove(deviceId);
-    d->trusted_devices->sync();
+    d->m_trustedDevices->remove(deviceId);
+    d->m_trustedDevices->sync();
     //We do not remove the config files.
 }
 
 // Utility functions to set and get a value
-void KdeConnectConfig::setDeviceProperty(QString deviceId, QString key, QString value)
+void KdeConnectConfig::setDeviceProperty(const QString& deviceId, const QString& key, const QString& value)
 {
-    d->trusted_devices->beginGroup(deviceId);
-    d->trusted_devices->setValue(key, value);
-    d->trusted_devices->endGroup();
-    d->trusted_devices->sync();
+    d->m_trustedDevices->beginGroup(deviceId);
+    d->m_trustedDevices->setValue(key, value);
+    d->m_trustedDevices->endGroup();
+    d->m_trustedDevices->sync();
 }
 
-QString KdeConnectConfig::getDeviceProperty(QString deviceId, QString key, QString defaultValue)
+QString KdeConnectConfig::getDeviceProperty(const QString& deviceId, const QString& key, const QString& defaultValue)
 {
     QString value;
-    d->trusted_devices->beginGroup(deviceId);
-    value = d->trusted_devices->value(key, defaultValue).toString();
-    d->trusted_devices->endGroup();
+    d->m_trustedDevices->beginGroup(deviceId);
+    value = d->m_trustedDevices->value(key, defaultValue).toString();
+    d->m_trustedDevices->endGroup();
     return value;
 }
 
 
-QDir KdeConnectConfig::deviceConfigDir(const QString &deviceId)
+QDir KdeConnectConfig::deviceConfigDir(const QString& deviceId)
 {
     QString deviceConfigPath = baseConfigDir().absoluteFilePath(deviceId);
     return QDir(deviceConfigPath);
 }
 
-QDir KdeConnectConfig::pluginConfigDir(const QString &deviceId, const QString &pluginName)
+QDir KdeConnectConfig::pluginConfigDir(const QString& deviceId, const QString& pluginName)
 {
     QString deviceConfigPath = baseConfigDir().absoluteFilePath(deviceId);
     QString pluginConfigDir = QDir(deviceConfigPath).absoluteFilePath(pluginName);
