@@ -60,6 +60,10 @@ QHash<int, QByteArray> NotificationsModel::roleNames() const
     names.insert(AppNameModelRole,     "appName");
     names.insert(IdModelRole,          "notificationId");
     names.insert(DismissableModelRole, "dismissable");
+    names.insert(RepliableModelRole, "repliable");
+    names.insert(IconPathModelRole, "appIcon");
+    names.insert(TitleModelRole, "title");
+    names.insert(TextModelRole, "notitext");
     return names;
 }
 
@@ -130,7 +134,7 @@ void NotificationsModel::refreshNotificationList()
     }
 
     QDBusPendingReply<QStringList> pendingNotificationIds = m_dbusInterface->activeNotifications();
-    QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(pendingNotificationIds, this);
+    QDBusPendingCallWatcher* watcher = new QDBusPendingCallWatcher(pendingNotificationIds, this);
 
     QObject::connect(watcher, &QDBusPendingCallWatcher::finished,
                      this, &NotificationsModel::receivedNotifications);
@@ -153,7 +157,7 @@ void NotificationsModel::receivedNotifications(QDBusPendingCallWatcher* watcher)
     }
 
     beginInsertRows(QModelIndex(), 0, notificationIds.size() - 1);
-    Q_FOREACH (const QString& notificationId, notificationIds) {
+    for (const QString& notificationId : notificationIds) {
         NotificationDbusInterface* dbusInterface = new NotificationDbusInterface(m_deviceId, notificationId, this);
         m_notificationList.append(dbusInterface);
     }
@@ -192,6 +196,14 @@ QVariant NotificationsModel::data(const QModelIndex& index, int role) const
             return qVariantFromValue<QObject*>(notification);
         case DismissableModelRole:
             return notification->dismissable();
+        case RepliableModelRole:
+            return !notification->replyId().isEmpty();
+        case IconPathModelRole:
+            return notification->iconPath();
+        case TitleModelRole:
+            return notification->title();
+        case TextModelRole:
+            return notification->text();
         default:
              return QVariant();
     }
@@ -223,7 +235,7 @@ int NotificationsModel::rowCount(const QModelIndex& parent) const
 
 bool NotificationsModel::isAnyDimissable() const
 {
-    Q_FOREACH (NotificationDbusInterface* notification, m_notificationList) {
+    for (NotificationDbusInterface* notification : qAsConst(m_notificationList)) {
         if (notification->dismissable()) {
             return true;
         }
@@ -233,7 +245,7 @@ bool NotificationsModel::isAnyDimissable() const
 
 void NotificationsModel::dismissAll()
 {
-    Q_FOREACH (NotificationDbusInterface* notification, m_notificationList) {
+    for (NotificationDbusInterface* notification : qAsConst(m_notificationList)) {
         if (notification->dismissable()) {
             notification->dismiss();
         }
