@@ -48,8 +48,8 @@ MprisControlPlugin::MprisControlPlugin(QObject* parent, const QVariantList& args
     connect(QDBusConnection::sessionBus().interface(), &QDBusConnectionInterface::serviceOwnerChanged, this, &MprisControlPlugin::serviceOwnerChanged);
 
     //Add existing interfaces
-    QStringList services = QDBusConnection::sessionBus().interface()->registeredServiceNames().value();
-    Q_FOREACH (const QString& service, services) {
+    const QStringList services = QDBusConnection::sessionBus().interface()->registeredServiceNames().value();
+    for (const QString& service : services) {
         // The string doesn't matter, it just needs to be empty/non-empty
         serviceOwnerChanged(service, QLatin1String(""), QStringLiteral("1"));
     }
@@ -81,8 +81,14 @@ void MprisControlPlugin::addPlayer(const QString& service)
     if (identity.isEmpty()) {
         identity = service.mid(sizeof("org.mpris.MediaPlayer2"));
     }
-    playerList[identity] = service;
-    qCDebug(KDECONNECT_PLUGIN_MPRIS) << "Mpris addPlayer" << service << "->" << identity;
+
+    QString uniqueName = identity;
+    for (int i = 1 ; !playerList[uniqueName].isEmpty() ; i++) {
+        uniqueName = identity + " [" + i + "]";
+    }
+
+    playerList[uniqueName] = service;
+    qCDebug(KDECONNECT_PLUGIN_MPRIS) << "Mpris addPlayer" << service << "->" << uniqueName;
     sendPlayerList();
 
     OrgFreedesktopDBusPropertiesInterface* freedesktopInterface = new OrgFreedesktopDBusPropertiesInterface(service, QStringLiteral("/org/mpris/MediaPlayer2"), QDBusConnection::sessionBus(), this);
