@@ -20,27 +20,23 @@
 
 #include "notificationsdbusinterface.h"
 #include "notification_debug.h"
+#include "notification.h"
 
 #include <QDBusConnection>
 
-#include <KNotification>
-#include <QIcon>
-#include <QCryptographicHash>
-
 #include <core/device.h>
 #include <core/kdeconnectplugin.h>
-#include <core/filetransferjob.h>
 
 #include "notificationsplugin.h"
+#include "sendreplydialog.h"
 
 NotificationsDbusInterface::NotificationsDbusInterface(KdeConnectPlugin* plugin)
     : QDBusAbstractAdaptor(const_cast<Device*>(plugin->device()))
-    , mDevice(plugin->device())
-    , mPlugin(plugin)
-    , mLastId(0)
-    , imagesDir(QDir::temp().absoluteFilePath("kdeconnect"))
+    , m_device(plugin->device())
+    , m_plugin(plugin)
+    , m_lastId(0)
 {
-    imagesDir.mkpath(imagesDir.absolutePath());
+
 }
 
 NotificationsDbusInterface::~NotificationsDbusInterface()
@@ -50,26 +46,26 @@ NotificationsDbusInterface::~NotificationsDbusInterface()
 
 void NotificationsDbusInterface::clearNotifications()
 {
-    qDeleteAll(mNotifications);
-    mNotifications.clear();
+    qDeleteAll(m_notifications);
+    m_notifications.clear();
     Q_EMIT allNotificationsRemoved();
 }
 
 QStringList NotificationsDbusInterface::activeNotifications()
 {
-    return mNotifications.keys();
+    return m_notifications.keys();
 }
 
 void NotificationsDbusInterface::processPackage(const NetworkPackage& np)
 {
-    if (np.get<bool>("isCancel")) {
-        QString id = np.get<QString>("id");
+    if (np.get<bool>(QStringLiteral("isCancel"))) {
+        QString id = np.get<QString>(QStringLiteral("id"));
         // cut off kdeconnect-android's prefix if there:
-        if (id.startsWith("org.kde.kdeconnect_tp::"))
-            id = id.mid(id.indexOf("::") + 2);
+        if (id.startsWith(QLatin1String("org.kde.kdeconnect_tp::")))
+            id = id.mid(id.indexOf(QLatin1String("::")) + 2);
         removeNotification(id);
-    } else if (np.get<bool>("isRequest")) {
-        Q_FOREACH (const auto& n, mNotifications) {
+    } else if (np.get<bool>(QStringLiteral("isRequest"))) {
+        for (const auto& n : qAsConst(m_notifications)) {
             NetworkPackage np(PACKAGE_TYPE_NOTIFICATION_REQUEST, {
                 {"id", n->internalId()},
                 {"appName", n->appName()},
@@ -77,34 +73,20 @@ void NotificationsDbusInterface::processPackage(const NetworkPackage& np)
                 {"isClearable", n->dismissable()},
                 {"requestAnswer", true}
             });
-            mPlugin->sendPackage(np);
+            m_plugin->sendPackage(np);
         }
+    } else if(np.get<bool>(QStringLiteral("requestAnswer"), false)) {
+
     } else {
+        QString id = np.get<QString>(QStringLiteral("id"));
 
-        //TODO: Uncoment when we are able to display app icon on plasmoid
-        QString destination;
-        /*
-        if (np.hasPayload()) {
-            QString filename = KMD5(np.get<QString>("appName").toLatin1()).hexDigest();  //TODO: Store with extension?
-            destination = imagesDir.absoluteFilePath(filename);
-            FileTransferJob* job = np.createPayloadTransferJob(destination);
-            job->start();
+        if (!m_internalIdToPublicId.contains(id)) {
+            Notification* noti = new Notification(np, this);
+            addNotification(noti);
+        } else {
+            QString pubId = m_internalIdToPublicId[id];
+            m_notifications[pubId]->update(np);
         }
-        */
-
-        Notification* noti = new Notification(np, destination, this);
-
-        //Do not show updates to existent notification nor answers to a initialization request
-        if (!mInternalIdToPublicId.contains(noti->internalId()) && !np.get<bool>("requestAnswer", false) && !np.get<bool>("silent", false)) {
-            KNotification* notification = new KNotification("notification", KNotification::CloseOnTimeout, this);
-            notification->setIconName(QStringLiteral("preferences-desktop-notification"));
-            notification->setComponentName("kdeconnect");
-            notification->setTitle(mDevice->name());
-            notification->setText(noti->appName() + ": " + noti->ticker());
-            notification->sendEvent();
-        }
-
-        addNotification(noti);
     }
 }
 
@@ -112,7 +94,7 @@ void NotificationsDbusInterface::addNotification(Notification* noti)
 {
     const QString& internalId = noti->internalId();
 
-    if (mInternalIdToPublicId.contains(internalId)) {
+    if (m_internalIdToPublicId.contains(internalId)) {
         removeNotification(internalId);
     }
 
@@ -120,12 +102,16 @@ void NotificationsDbusInterface::addNotification(Notification* noti)
 
     connect(noti, &Notification::dismissRequested,
             this, &NotificationsDbusInterface::dismissRequested);
+    
+    connect(noti, &Notification::replyRequested, this, [this,noti]{ 
+        replyRequested(noti); 
+    });
 
     const QString& publicId = newId();
-    mNotifications[publicId] = noti;
-    mInternalIdToPublicId[internalId] = publicId;
+    m_notifications[publicId] = noti;
+    m_internalIdToPublicId[internalId] = publicId;
 
-    QDBusConnection::sessionBus().registerObject(mDevice->dbusPath()+"/notifications/"+publicId, noti, QDBusConnection::ExportScriptableContents);
+    QDBusConnection::sessionBus().registerObject(m_device->dbusPath()+"/notifications/"+publicId, noti, QDBusConnection::ExportScriptableContents);
     Q_EMIT notificationPosted(publicId);
 }
 
@@ -133,14 +119,14 @@ void NotificationsDbusInterface::removeNotification(const QString& internalId)
 {
     //qCDebug(KDECONNECT_PLUGIN_NOTIFICATION) << "removeNotification" << internalId;
 
-    if (!mInternalIdToPublicId.contains(internalId)) {
+    if (!m_internalIdToPublicId.contains(internalId)) {
         qCDebug(KDECONNECT_PLUGIN_NOTIFICATION) << "Not found noti by internal Id: " << internalId;
         return;
     }
 
-    QString publicId = mInternalIdToPublicId.take(internalId);
+    QString publicId = m_internalIdToPublicId.take(internalId);
 
-    Notification* noti = mNotifications.take(publicId);
+    Notification* noti = m_notifications.take(publicId);
     if (!noti) {
         qCDebug(KDECONNECT_PLUGIN_NOTIFICATION) << "Not found noti by public Id: " << publicId;
         return;
@@ -156,8 +142,8 @@ void NotificationsDbusInterface::removeNotification(const QString& internalId)
 void NotificationsDbusInterface::dismissRequested(const QString& internalId)
 {
     NetworkPackage np(PACKAGE_TYPE_NOTIFICATION_REQUEST);
-    np.set<QString>("cancel", internalId);
-    mPlugin->sendPackage(np);
+    np.set<QString>(QStringLiteral("cancel"), internalId);
+    m_plugin->sendPackage(np);
 
     //Workaround: we erase notifications without waiting a repsonse from the
     //phone because we won't receive a response if we are out of sync and this
@@ -166,7 +152,26 @@ void NotificationsDbusInterface::dismissRequested(const QString& internalId)
     removeNotification(internalId);
 }
 
+void NotificationsDbusInterface::replyRequested(Notification* noti)
+{
+    QString replyId = noti->replyId();
+    QString appName = noti->appName();
+    QString originalMessage = noti->ticker();
+    SendReplyDialog* dialog = new SendReplyDialog(originalMessage, replyId, appName);
+    connect(dialog, &SendReplyDialog::sendReply, this, &NotificationsDbusInterface::sendReply);
+    dialog->show();
+    dialog->raise();
+}
+
+void NotificationsDbusInterface::sendReply(const QString& replyId, const QString& message)
+{
+    NetworkPackage np(PACKAGE_TYPE_NOTIFICATION_REPLY);
+    np.set<QString>(QStringLiteral("requestReplyId"), replyId);
+    np.set<QString>(QStringLiteral("message"), message);
+    m_plugin->sendPackage(np);
+}
+
 QString NotificationsDbusInterface::newId()
 {
-    return QString::number(++mLastId);
+    return QString::number(++m_lastId);
 }
