@@ -87,13 +87,14 @@ bool SharePlugin::receivePackage(const NetworkPackage& np)
     qCDebug(KDECONNECT_PLUGIN_SHARE) << "File transfer";
 
     if (np.hasPayload()) {
-        //qCDebug(KDECONNECT_PLUGIN_SHARE) << "receiving file";
         const QString filename = np.get<QString>(QStringLiteral("filename"), QString::number(QDateTime::currentMSecsSinceEpoch()));
         const QUrl dir = destinationDir().adjusted(QUrl::StripTrailingSlash);
-        QUrl destination(dir.toString() + '/' + filename);
+        QUrl destination(dir);
+        destination.setPath(dir.path() + '/' + filename, QUrl::DecodedMode);
         if (destination.isLocalFile() && QFile::exists(destination.toLocalFile())) {
-            destination = QUrl(dir.toString() + '/' + KIO::suggestName(dir, filename));
+            destination.setPath(dir.path() + '/' + KIO::suggestName(dir, filename), QUrl::DecodedMode);
         }
+//         qCDebug(KDECONNECT_PLUGIN_SHARE) << "receiving file" << filename << "in" << dir << "into" << destination;
 
         FileTransferJob* job = np.createPayloadTransferJob(destination);
         job->setOriginName(device()->name() + ": " + filename);
@@ -115,29 +116,30 @@ bool SharePlugin::receivePackage(const NetworkPackage& np)
             tmpFile.write(text.toUtf8());
             tmpFile.close();
 
-            const QUrl url = QUrl::fromLocalFile(tmpFile.fileName());
-            Q_EMIT shareReceived(url);
-            QDesktopServices::openUrl(url);
+            const QString fileName = tmpFile.fileName();
+            Q_EMIT shareReceived(fileName);
+            QDesktopServices::openUrl(QUrl::fromLocalFile(fileName));
         }
     } else if (np.has(QStringLiteral("url"))) {
         QUrl url = QUrl::fromEncoded(np.get<QByteArray>(QStringLiteral("url")));
         QDesktopServices::openUrl(url);
-        Q_EMIT shareReceived(url);
+        Q_EMIT shareReceived(url.toString());
     } else {
         qCDebug(KDECONNECT_PLUGIN_SHARE) << "Error: Nothing attached!";
     }
 
     return true;
-
 }
 
 void SharePlugin::finished(KJob* job)
 {
     FileTransferJob* ftjob = qobject_cast<FileTransferJob*>(job);
-    if (ftjob)
-        Q_EMIT shareReceived(ftjob->destination());
-
-    qCDebug(KDECONNECT_PLUGIN_SHARE) << "File transfer finished. Success:" << (!job->error()) << (ftjob ? ftjob->destination() : QUrl());
+    if (ftjob && !job->error()) {
+        Q_EMIT shareReceived(ftjob->destination().toString());
+        qCDebug(KDECONNECT_PLUGIN_SHARE) << "File transfer finished." << ftjob->destination();
+    } else {
+        qCDebug(KDECONNECT_PLUGIN_SHARE) << "File transfer failed." << (ftjob ? ftjob->destination() : QUrl());
+    }
 }
 
 void SharePlugin::openDestinationFolder()
@@ -158,11 +160,6 @@ void SharePlugin::shareUrl(const QUrl& url)
     sendPackage(package);
 }
 
-void SharePlugin::connected()
-{
-    QDBusConnection::sessionBus().registerObject(dbusPath(), this, QDBusConnection::ExportScriptableContents);
-}
-
 QString SharePlugin::dbusPath() const
 {
     return "/modules/kdeconnect/devices/" + device()->id() + "/share";
